#
# spec file for package raspberrypi-eeprom
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} < 1550
%define _firmwaredir /lib/firmware
%endif

Name:           raspberrypi-eeprom
Version:        2021.04.29
Release:        150300.3.3.1
Summary:        Raspberry Pi 4 EEPROM firmware
License:        SUSE-Firmware
Group:          System/Boot
URL:            https://github.com/raspberrypi/rpi-eeprom
Source0:        %{name}-%{version}.tar.xz
Patch0:         add-suse-config.patch
Patch1:         dont-use-env.patch
Patch2:         rpi-eeprom-update-Use-tr-instead-of-strings.patch
Provides:       rpi-eeprom
Supplements:    modalias(of:N*T*Cbrcm%2Cbcm2711*C*)
Requires:       raspberrypi-firmware >= 2021.03.03
Requires:       raspberrypi-firmware-dt >= 2021.03.03
Provides:       rpi-eeprom-config = %{version}
Obsoletes:      rpi-eeprom-config < %{version}
Requires:       pciutils
Requires:       raspberrypi-eeprom-firmware
BuildArch:      noarch

%description
First stage bootloader packages for Raspberry Pi 4

%package firmware
Summary:        Raspberry Pi 4 EEPROM firmware blobs
Group:          System/Boot
Provides:       raspberrypi-firmware-eeprom = %{version}
Obsoletes:      raspberrypi-firmware-eeprom < %{version}
Requires:       raspberrypi-eeprom
BuildRequires:  fdupes

%description firmware
First stage bootloader fimware blobs for Raspberry Pi 4

%prep
%autosetup -p1

%build

%install
mkdir -p %{buildroot}%{_bindir}
install -m 0755 rpi-eeprom-config %{buildroot}%{_bindir}
install -m 0755 rpi-eeprom-update %{buildroot}%{_bindir}
mkdir -p %{buildroot}/etc/default
install -m 644 rpi-eeprom-update-default %{buildroot}/etc/default/rpi-eeprom-update

mkdir -p %{buildroot}/%{_firmwaredir}/raspberrypi/bootloader
mv firmware/beta %{buildroot}/%{_firmwaredir}/raspberrypi/bootloader
mv firmware/critical %{buildroot}/%{_firmwaredir}/raspberrypi/bootloader
mv firmware/stable %{buildroot}/%{_firmwaredir}/raspberrypi/bootloader
cp -a firmware/latest %{buildroot}/%{_firmwaredir}/raspberrypi/bootloader
cp -a firmware/default %{buildroot}/%{_firmwaredir}/raspberrypi/bootloader
%fdupes -s %{buildroot}/%{_firmwaredir}/raspberrypi/bootloader

%files
%license LICENSE
%{_bindir}/rpi-eeprom-config
%{_bindir}/rpi-eeprom-update
%config /etc/default/rpi-eeprom-update

%files firmware
%{_firmwaredir}
%{_firmwaredir}/raspberrypi
%{_firmwaredir}/raspberrypi/bootloader/beta
%{_firmwaredir}/raspberrypi/bootloader/critical
%{_firmwaredir}/raspberrypi/bootloader/stable
%{_firmwaredir}/raspberrypi/bootloader/latest
%{_firmwaredir}/raspberrypi/bootloader/default

%changelog
* Wed Jun 30 2021 rpm@fthiessen.de
- Use upstream version schema (year.month.day) instead of arbitrary 0.0
- Update to version 2021.04.29
  * Add support for NVMe to the bootloader with a new NVMe boot mode
  * Add support for [cm4] and [pi400] config conditionals filters.
  * TFTP - reply to duplicate ACKS
  * Skip rendering of HDMI diagnostics display for the first 8 seconds
    unless an error occurs.
  * Add support for the BCM2711 XHCI controller - BOOT_ORDER 0x5
  * XHCI protocol layer fixes for non-VLI controllers
  * Avoid USB MSD timeout of there is only one device
  * Fix recovery.bin error handler so that the LED error pattern
    is still displayed even if HDMI or SDRAM fail.
  * Fix GPIO expander reset issue on some Pi4B 1.1 to 1.3 boards
  * Fix regression for GPIO expander reset change which caused PMIC
    reset to get card out of 1V8 mode to be missed.
  * Timeout USB MSD commands and move to the next boot mode if a device
    stops responding.
  * Add support for booting from the BCM2711 XHCI controller which is
    the USB-C socket on Pi 4B / Pi 400 and the type A sockets on Compute
    Module 4 IO board.
  * Validate SDRAM in recovery mode.
- Fixes bsc#1194950.
* Fri Feb 19 2021 nsaenzjulienne@suse.com
- Add 'pciutils' as a requirement. 'rpi-eeprom-update' uses lspci.
  (bsc#1182437)
- Update to version 0.0~2020.09.03.65~gb9c255d: Simplifies code by removing
  legacy functions.
- Add patch: "rpi-eeprom-update-Use-tr-instead-of-strings.patch" to avoid the
  dependency with binutils. (bsc#1182437)
* Thu Feb  4 2021 nsaenzjulienne@suse.com
- Fix 'Supplements:' in spec file, as per
  https://doc.opensuse.org/projects/libzypp/HEAD/zypp-modalias.html commas are
  special charactes that should be replaced with '%%2C'
* Thu Jan 28 2021 nsaenzjulienne@suse.com
- Remove VL805 firmware version from package version as it prevents it from
  incresing monotonically.
* Thu Jan 28 2021 guillaume.gardet@opensuse.org
- Prefix version with 0.0~
* Wed Jan 27 2021 nsaenzjulienne@suse.com
- Define _firmwaredir when relevant
* Tue Jan 26 2021 nsaenzjulienne@suse.com
- Update to b9c255d:
  * rpi-eeprom-config: Properly decode sysfs binary files
* Mon Jan 25 2021 nsaenzjulienne@suse.com
- Introduce _service file.
* Mon Jan 25 2021 jengelh@inai.de
- Ditch unnecessarily split package.
* Fri Jan 22 2021 nsaenzjulienne@suse.com
- First commit
- Introduce patches: 'add-suse-config.patch' and 'don't-use-env.patch'.
